@@ -5,29 +5,19 @@ from cymysql.constants import ER
 PYTHON3 = sys.version_info[0] > 2
 
 if PYTHON3:
-    class MySQLError(Exception):
+    StandardError = Exception
 
-        """Exception related to operation with MySQL."""
-        def __init__(self, *args):
-            if len(args) == 2:
-                self.errno = args[0]
-                self.errmsg = args[1]
-            else:
-                self.errno = -1
-                self.errmsg = args[0]
-            super(MySQLError, self).__init__(*args)
-else:
-    class MySQLError(StandardError):
-    
-        """Exception related to operation with MySQL."""
-        def __init__(self, *args):
-            if len(args) == 2:
-                self.errno = args[0]
-                self.errmsg = args[1]
-            else:
-                self.errno = -1
-                self.errmsg = args[0]
-            super(MySQLError, self).__init__(*args)
+class MySQLError(StandardError):
+
+    """Exception related to operation with MySQL."""
+    def __init__(self, *args):
+        if len(args) == 2:
+            self.errno = args[0]
+            self.errmsg = args[1]
+        else:
+            self.errno = -1
+            self.errmsg = args[0]
+        super(MySQLError, self).__init__(*args)
 
 class Warning(MySQLError):
 
